@@ -21,7 +21,7 @@ from libopensesame.py3compat import *
 from distutils.version import StrictVersion
 import sys
 
-__version__ = u'3.1.9'
+__version__ = u'3.2.0'
 strict_version = StrictVersion(__version__)
 # The version without the prerelease (if any): e.g. 3.0.0
 main_version = u'.'.join([str(i) for i in strict_version.version])
@@ -30,9 +30,8 @@ if strict_version.prerelease is None:
 	deb_version = main_version
 else:
 	deb_version = main_version + u'+%s%d' % strict_version.prerelease
-python_version = u'%d.%d.%d' % (sys.version_info[0], sys.version_info[1], \
-	sys.version_info[2])
-codename = u'Jazzy James'
+python_version = u'%d.%d.%d' % sys.version_info[:3]
+codename = u'Kafkaesque Koffka'
 channel = u'dev'
-api = StrictVersion(u'2.0')
+api = StrictVersion(u'2.1')
 platform = sys.platform
