@@ -24,8 +24,20 @@ import re
 import os
 try:
 	import markdown
-	from markdown.extensions import attr_list, extra, toc
+	from distutils.version import LooseVersion
+	# TocExtension() doesn't support the title keyword in previous versions
+	# This seems to have been added in 2.6 as part of the depraction of the 
+	# HeaderID extension: 
+	# https://github.com/waylan/Python-Markdown/releases/tag/2.6-final
+	if LooseVersion(markdown.version) > LooseVersion(u'2.6'):
+		from markdown.extensions import attr_list, extra, toc
+	else:
+		from libopensesame import debug
+		debug.msg(u'Markdown disabled for markdown version: {}'.format(markdown.version))
+		markdown = None
 except:
+	from libopensesame import debug
+	debug.msg(u'Unable to import markdown, proceeding without markdown')
 	markdown = None
 try:
 	from pygments import highlight
@@ -60,8 +72,8 @@ class markdown_parser(base_subcomponent):
 
 		self.setup(main_window)
 		self.css = u'<style type="text/css">'
-		with open(self.main_window.theme.resource(u'markdown.css')) as fd:
-			self.css += safe_decode(fd.read()) % {u'background_image' : \
+		with safe_open(self.main_window.theme.resource(u'markdown.css')) as fd:
+			self.css += fd.read() % {u'background_image' : \
 				os.path.abspath(self.main_window.theme.resource(
 				u'background.png'))}
 		if highlight is not None:
@@ -83,7 +95,7 @@ class markdown_parser(base_subcomponent):
 
 <div class="footer">
 OpenSesame %s %s —
-Copyright <a href="http://www.cogsci.nl/smathot">Sebastiaan Mathôt</a> 2010-2016
+Copyright <a href="http://www.cogsci.nl/smathot">Sebastiaan Mathôt</a> 2010-2017
 </div>
 ''' % (_(u'Dismiss this message'), metadata.__version__, metadata.codename)
 
